# !!!WARNING!!! USING THIS ADDON IS NOT RECOMMEDED ANYMORE, PLEASE MIGRATE TO HELM RELEASE! Vault CSI driver

See more:
* https://github.com/hashicorp/vault-csi-provider
* https://learn.hashicorp.com/tutorials/vault/kubernetes-secret-store-driver
* https://www.vaultproject.io/docs/auth/kubernetes

basic YAML generated by:

```
helm template vault hashicorp/vault \
    --namespace=kube-system \
    --values=generate-values \
    > manifest.yaml
```

## Migrating away from static manifest to helm charts managed by KubeOne

### Delete old artifacts

```bash
kubectl delete -f manifest.yaml
```

## Configure Vault

Example configuration for AWS access.
You have to setup shell variables:
* `AWS_ACCESS_KEY_ID`
* `AWS_SECRET_ACCESS_KEY`
* `SERVICE_ACCOUNT_TOKEN`
  A token from service account with `ClusterRole` binding to `system:auth-delegator`
* `KUBERNETES_API_ENDPOINT`

and `ca.crt` file of your kubernetes CA Cert.

```shell
vault kv put secret/cloud-credentials \
    AWS_ACCESS_KEY_ID="${AWS_ACCESS_KEY_ID}" \
    AWS_SECRET_ACCESS_KEY="${AWS_SECRET_ACCESS_KEY}"

vault auth enable kubernetes

vault write auth/kubernetes/config \
    token_reviewer_jwt="${SERVICE_ACCOUNT_TOKEN}" \
    kubernetes_host="https://${KUBERNETES_API_ENDPOINT}:6443" \
    kubernetes_ca_cert=@ca.crt

vault policy write kubeone - <<EOF
path "secret/data/cloud-credentials" {
  capabilities = ["read"]
}
EOF

# following service accounts are used by the deployments that need access to
# credentials
vault write auth/kubernetes/role/kubeone \
    bound_service_account_names=machine-controller \
    bound_service_account_names=machine-controller-webhook \
    bound_service_account_names=operating-system-manager \
    bound_service_account_names=operating-system-manager-webhook \
    bound_service_account_names=cloud-controller-manager \
    bound_service_account_names=ebs-csi-controller-sa \
    bound_service_account_names=ebs-csi-node-sa \
    bound_service_account_namespaces=kube-system \
    policies=kubeone \
    ttl=20m
```

## Example SecretProviderClass to configure vault as a Secrets Store CSI Driver

```yaml
apiVersion: secrets-store.csi.x-k8s.io/v1
kind: SecretProviderClass
metadata:
  name: kubeone-credentials
  namespace: kube-system
spec:
  provider: vault
  secretObjects:
    # required Secret object for machinecontroller and its webhook
    - secretName: kubeone-machine-controller-credentials
      type: Opaque
      data:
        - objectName: AWS_ACCESS_KEY_ID
          key: AWS_ACCESS_KEY_ID
        - objectName: AWS_SECRET_ACCESS_KEY
          key: AWS_SECRET_ACCESS_KEY
    # required Secret object for CCM/CSI
    - secretName: kubeone-ccm-credentials
      type: Opaque
      data:
        - objectName: AWS_ACCESS_KEY_ID
          key: AWS_ACCESS_KEY_ID
        - objectName: AWS_SECRET_ACCESS_KEY
          key: AWS_SECRET_ACCESS_KEY
    # required Secret object for OSM
    - secretName: kubeone-operating-system-manager-credentials
      type: Opaque
      data:
        - objectName: AWS_ACCESS_KEY_ID
          key: AWS_ACCESS_KEY_ID
        - objectName: AWS_SECRET_ACCESS_KEY
          key: AWS_SECRET_ACCESS_KEY
  parameters:
    vaultAddress: "https://<YOUR_VAULT_ADDRESS>:8200"
    roleName: "kubeone"
    objects: |
      - objectName: "AWS_ACCESS_KEY_ID"
        secretPath: "secret/data/cloud-credentials"
        secretKey: "AWS_ACCESS_KEY_ID"
      - objectName: "AWS_SECRET_ACCESS_KEY"
        secretPath: "secret/data/cloud-credentials"
        secretKey: "AWS_SECRET_ACCESS_KEY"
```

Save this to ./addons/my-secret-provider-class/manifest.yaml

## Configure KubeOne

`kubeone apply` again to apply new `my-secret-provider-class` addon:

```yaml
apiVersion: kubeone.k8c.io/v1beta2
kind: KubeOneCluster

versions:
  kubernetes: 1.25.5

containerRuntime:
  containerd: {}

helmReleases:
  - chart: secrets-store-csi-driver
    repoURL: https://kubernetes-sigs.github.io/secrets-store-csi-driver/charts
    namespace: kube-system
    version: 1.3.0
    values:
      - inline:
          syncSecret:
            enabled: true
          enableSecretRotation: true
  - releaseName: vault-csi-driver
    chart: vault
    repoURL: https://helm.releases.hashicorp.com
    namespace: kube-system
    version: 0.23.0
    values:
      - inline:
          server:
            enabled: false
          injector:
            enabled: false
          csi:
            enabled: true

cloudProvider:
  secretProviderClassName: "kubeone-credentials"

addons:
  enable: true
  path: "./addons"
```
